@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,19 +10,22 @@
 #include <KCModule>
 
 #include <QVariant>
-namespace KUserFeedback {
+namespace KUserFeedback
+{
 class FeedbackConfigWidget;
 }
 
-namespace KAddressBook {
+namespace KAddressBook
+{
 class KCMKaddressbookUserFeedBackConfig : public KCModule
 {
     Q_OBJECT
 public:
-    KCMKaddressbookUserFeedBackConfig(QWidget *parent, const QVariantList &args);
+    explicit KCMKaddressbookUserFeedBackConfig(QWidget *parent, const QVariantList &args);
     void load() override;
     void save() override;
     void defaults() override;
+
 private:
     KUserFeedback::FeedbackConfigWidget *mUserFeedbackWidget = nullptr;
 };
