@@ -7,10 +7,10 @@
 */
 
 #include "aboutdata.h"
-#include "mainwindow.h"
-#include "mainwidget.h"
 #include "kaddressbook_options.h"
 #include "kaddressbookmigrateapplication.h"
+#include "mainwidget.h"
+#include "mainwindow.h"
 
 #include <KCrash>
 #include <QCommandLineParser>
@@ -69,7 +69,7 @@ int main(int argc, char **argv)
 
 #ifdef WITH_KUSERFEEDBACK
     if (cmdArgs->isSet(QStringLiteral("feedback"))) {
-        auto *userFeedBack = new KAddressBookUserFeedbackProvider(nullptr);
+        auto userFeedBack = new KAddressBookUserFeedbackProvider(nullptr);
         QTextStream(stdout) << userFeedBack->describeDataSources() << '\n';
         delete userFeedBack;
         return 0;
